@@ -4,15 +4,15 @@ use Acme::Lingua::Pirate::Perl;
 
 Avast!
 
-my @doubloons = qw(avast ye scurvy swab!); Yarrr
+my @pieces_of_eight = qw(avast ye scurvy swab!); Yarrr!
 
-unless (steal @doubloons be 'avast') {
+unless (steal @pieces_of_eight be 'avast') {
   capsize "Arrrr, we be hit below the waterline!\n";
 }
 
 sound off "Type something, ye bilge rat! "; $_ = <>; chomp;
 
-cry "Ye entered 'the booty'!\n"; Yo ho ho!
+cry "Ye entered 'the gold'!\n"; Yo ho ho!
 
 sail off;
 
